@@ -1,14 +1,15 @@
-# -*- coding: latin-1 -*-
 # Copyright (c) 2007 Zope Foundation and Contributors
 # See also LICENSE.txt
-# $Id: message.py 117182 2010-10-02 13:07:54Z icemac $
+# $Id$
 """A simple message that can be displayed."""
 
 import persistent
-import z3c.flashmessage.interfaces
 import zope.interface
 
+import z3c.flashmessage.interfaces
 
+
+@zope.interface.implementer(z3c.flashmessage.interfaces.IMessage)
 class BaseMessage(persistent.Persistent):
     """A message that is displayed to the user.
 
@@ -16,9 +17,7 @@ class BaseMessage(persistent.Persistent):
 
     """
 
-    zope.interface.implements(z3c.flashmessage.interfaces.IMessage)
-
-    def __init__(self, message, type=u"message"):
+    def __init__(self, message, type="message"):
         self.message = message
         self.type = type
 
