@@ -1,7 +1,6 @@
-# -*- coding: latin-1 -*-
 # Copyright (c) 2007 Zope Foundation and Contributors
 # See also LICENSE.txt
-# $Id: receiver.py 113324 2010-06-10 09:48:02Z janwijbrand $
+# $Id$
 """A global message receiver that covers all sources."""
 
 import zope.interface
@@ -9,9 +8,8 @@ import zope.interface
 import z3c.flashmessage.interfaces
 
 
-class GlobalMessageReceiver(object):
-
-    zope.interface.implements(z3c.flashmessage.interfaces.IMessageReceiver)
+@zope.interface.implementer(z3c.flashmessage.interfaces.IMessageReceiver)
+class GlobalMessageReceiver:
 
     def receive(self, type=None):
         sources = zope.component.getAllUtilitiesRegisteredFor(
