@@ -1,17 +1,19 @@
-# -*- coding: latin-1 -*-
 # Copyright (c) 2007 Zope Foundation and Contributors
 # See also LICENSE.txt
-# $Id: tests.py 117188 2010-10-02 13:20:32Z icemac $
+# $Id$
 """Test harness"""
 
 import doctest
-import z3c.flashmessage
+
 import zope.app.wsgi.testlayer
 import zope.publisher.browser
 import zope.security.management
 
+import z3c.flashmessage
 
-FlashMessageLayer = zope.app.wsgi.testlayer.BrowserLayer(z3c.flashmessage)
+
+FlashMessageLayer = zope.app.wsgi.testlayer.BrowserLayer(
+    z3c.flashmessage, allowTearDown=True)
 
 
 def setUp(test):
@@ -23,7 +25,7 @@ def setUp(test):
 
 def test_suite():
     suite = doctest.DocFileSuite(
-        'README.txt',
+        'README.rst',
         optionflags=doctest.ELLIPSIS,
         setUp=setUp)
     suite.layer = FlashMessageLayer
